@@ -35,7 +35,7 @@ sub print_repo_info {
     prop_line "Forks"      , $ret->{forks};
     prop_line "Open Issues"     , $ret->{open_issues};
     prop_line "Created at" , $ret->{created_at};
-    prop_line "Pushed at"  , $ret->{pushed_at};
+    prop_line "Pushed at"  , $ret->{pushed_at} || "never";
 
     print ' ' x 15 . "* Is private\n"    if $ret->{private};
     print ' ' x 15 . "* Has downloads\n" if $ret->{has_downloads};
